OtpController class
Constructors
Properties
-
focusedIndex
→ Rx<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isSahking
→ Rx<
bool> -
final
-
numbers
→ Rx<
List< String> > -
latefinal
-
onCodeSubmitted
↔ Future<
bool> Function(String code)? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKeyPadPressed(
String x) → dynamic -
setConfig(
int length, Future< bool> onCodeSubmitted(String code)) → dynamic -
shake(
) → dynamic -
showToast(
String message) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited